@@ -24,6 +24,8 @@
   parameters <- insight::get_parameters(model, effects = effects, component = component)
   statistic <- insight::get_statistic(model, component = component)
 
+  # check if all estimates are non-NA
+  parameters <- .check_rank_deficiency(parameters)
 
   # ==== check if we really have a component column
 
@@ -215,6 +217,9 @@
   parameters <- insight::get_parameters(model, effects = "fixed", component = "all")
   statistic <- insight::get_statistic(model, component = "all")
 
+  # check if all estimates are non-NA
+  parameters <- .check_rank_deficiency(parameters)
+
   # sometimes, due to merge(), row-order messes up, so we save this here
   original_order <- parameters$.id <- 1:nrow(parameters)
 
@@ -765,3 +770,13 @@
   row.names(out) <- NULL
   out
 }
+
+
+
+.check_rank_deficiency <- function(p, verbose = TRUE) {
+  if (anyNA(p$Estimate)) {
+    if (isTRUE(verbose)) warning(sprintf("Model matrix is rank deficient. Parameters %s were not estimable.", paste(p$Parameter[is.na(p$Estimate)], collapse = ", ")), call. = FALSE)
+    p <- p[!is.na(p$Estimate), ]
+  }
+  p
+}
