@@ -1,9 +1,10 @@
-#' p-values using Satterthwaite approximation
+#' Satterthwaite approximation for SEs, CIs and p-values
 #'
 #' An approximate F-test based on the Satterthwaite (1946) approach.
 #'
 #' @param model A statistical model.
 #' @param dof Degrees of Freedom.
+#' @inheritParams ci.merMod
 #'
 #' @details Inferential statistics (like p-values, confidence intervals and
 #' standard errors) may be biased in mixed models when the number of clusters
@@ -19,17 +20,17 @@
 #' to calculate approximated degrees of freedom and standard errors for model
 #' parameters, based on the Satterthwaite (1946) approach.
 #' \cr \cr
-#' \code{\link{dof_kenward}} and \code{\link{dof_ml1}} approximate degrees
-#' of freedom bases on Kenward-Roger's method or the "m-l-1" rule.
+#' \code{\link[=dof_kenward]{dof_kenward()}} and \code{\link[=dof_ml1]{dof_ml1()}}
+#' approximate degrees of freedom based on Kenward-Roger's method or the "m-l-1" rule.
 #'
 #' @examples
 #' \donttest{
-#' library(lme4)
-#' model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
-#' p_value_satterthwaite(model)
+#' if (require("lme4")) {
+#'   model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
+#'   p_value_satterthwaite(model)
 #' }
-#'
-#' @return The p-values.
+#' }
+#' @return A data frame.
 #' @references Satterthwaite FE (1946) An approximate distribution of estimates of variance components. Biometrics Bulletin 2 (6):110–4.
 #' @importFrom stats pt coef
 #' @export
@@ -43,24 +44,17 @@ p_value_satterthwaite.lmerMod <- function(model, dof = NULL) {
   if (is.null(dof)) {
     dof <- dof_satterthwaite(model)
   }
-
-  params <- as.data.frame(stats::coef(summary(model)))
-
-  if ("t value" %in% names(params)) {
-    p <- 2 * stats::pt(abs(params[, "t value"]), df = dof, lower.tail = FALSE)
-  } else {
-    stop("Couldn't find any suitable statistic (t value) for Satterthwaite approximation.")
-  }
-
-  if (is.null(names(p))) {
-    coef_names <- rownames(params)
-  } else {
-    coef_names <- names(p)
-  }
-
-  data.frame(
-    Parameter = coef_names,
-    p = unname(p),
-    stringsAsFactors = FALSE
-  )
+  .p_value_dof(model, dof, method = "satterthwaite")
 }
+
+
+#' @export
+p_value_satterthwaite.lme <- function(model, dof = NULL) {
+  if (is.null(dof)) {
+    dof <- dof_satterthwaite(model)
+  }
+  .p_value_dof(model, dof, method = "satterthwaite")
+}
+
+#' @export
+p_value_satterthwaite.gls <- p_value_satterthwaite.lme
