@@ -259,6 +259,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
       "zero_inflated.fixed" = "Fixed Effects (Zero-Inflated Model)",
       "zero_inflated.random" = "Random Effects (Zero-Inflated Model)",
       "dispersion" = "Dispersion",
+      "marginal" = "Marginal Effects",
       "simplex.fixed" = ,
       "simplex" = "Monotonic Effects",
       "smooth_sd" = "Smooth Terms (SD)",
@@ -365,4 +366,8 @@ print.parameters_stan <- function(x, split_components = TRUE, select = NULL, ...
     }
   }
   invisible(orig_x)
-}
\ No newline at end of file
+}
+
+
+#' @export
+print.parameters_simulate <- print.parameters_model
